@@ -1,3 +1,11 @@
+setMethod("asJSON", "blob", function(x, raw = "base64", ...){
+  if(identical(raw, "base64")){
+    str <- vapply(x, base64_enc, character(1))
+    return(asJSON(str, ...))
+  }
+  asJSON(as.list(x), raw = raw, ...)
+})
+
 setMethod("asJSON", "raw", function(x, raw = c("base64", "hex", "mongo", "int", "js"), ...) {
 
   # validate
